@@ -13,8 +13,6 @@
 #include <eog-image.h>
 
 #define WINDOW_DATA_KEY "EogReloadWindowData"
-/*#define MENU_PATH "/MainMenu/ImageMenu/Reload"*/
-#define MENU_PATH "/MainMenu/ToolsMenu/ToolsOps_3"
 
 EOG_PLUGIN_REGISTER_TYPE(EogReloadPlugin, eog_reload_plugin)
 
@@ -31,12 +29,21 @@ reload_cb (GtkAction	*action,
         eog_window_reload_image (window);
 }
 
+static const gchar * const ui_definition =
+	"<ui><menubar name=\"MainMenu\">"
+	"<menu name=\"ToolsMenu\" action=\"Tools\"><separator/>"
+	"<menuitem name=\"EogPluginReload\" action=\"EogPluginRunReload\"/>"
+	"<separator/></menu></menubar>"
+	"<popup name=\"ViewPopup\"><separator/>"
+	"<menuitem action=\"EogPluginRunReload\"/><separator/>"
+	"</popup></ui>";
+
 static const GtkActionEntry action_entries[] =
 {
-	{ "RunReload",
+	{ "EogPluginRunReload",
 	  GTK_STOCK_REFRESH,
 	  N_("Reload Image"),
-	  "<control><shift>R",
+	  "R",
 	  N_("Reload current image"),
 	  G_CALLBACK (reload_cb) }
 };
@@ -45,11 +52,11 @@ static void
 free_window_data (WindowData *data)
 {
 	g_return_if_fail (data != NULL);
-	
+
 	eog_debug (DEBUG_PLUGINS);
 
 	g_object_unref (data->ui_action_group);
-	
+
 	g_free (data);
 }
 
@@ -74,18 +81,18 @@ impl_activate (EogPlugin *plugin,
 	GtkUIManager *manager;
         GList *action_groups;
 	WindowData *data;
-	
+
 	eog_debug (DEBUG_PLUGINS);
 
 	data = g_new (WindowData, 1);
 
 	manager = eog_window_get_ui_manager (window);
 
-	action_groups = gtk_ui_manager_get_action_groups (manager); 
+	action_groups = gtk_ui_manager_get_action_groups (manager);
 
 	data->ui_action_group = gtk_action_group_new ("EogReloadPluginActions");
-	
-	gtk_action_group_set_translation_domain (data->ui_action_group, 
+
+	gtk_action_group_set_translation_domain (data->ui_action_group,
 						 GETTEXT_PACKAGE);
 
 	gtk_action_group_add_actions (data->ui_action_group,
@@ -97,20 +104,15 @@ impl_activate (EogPlugin *plugin,
 					    data->ui_action_group,
 					    -1);
 
-	data->ui_id = gtk_ui_manager_new_merge_id (manager);
-
-	g_object_set_data_full (G_OBJECT (window), 
-				WINDOW_DATA_KEY, 
+	g_object_set_data_full (G_OBJECT (window),
+				WINDOW_DATA_KEY,
 				data,
 				(GDestroyNotify) free_window_data);
 
-	gtk_ui_manager_add_ui (manager, 
-			       data->ui_id, 
-			       MENU_PATH,
-			       "RunReload", 
-			       "RunReload",
-			       GTK_UI_MANAGER_MENUITEM, 
-			       FALSE);
+	data->ui_id = gtk_ui_manager_add_ui_from_string (manager,
+							 ui_definition,
+							 -1, NULL);
+	g_warn_if_fail (data->ui_id != 0);
 }
 
 static void
@@ -139,12 +141,6 @@ impl_deactivate	(EogPlugin *plugin,
 			   NULL);
 }
 
-static void
-impl_update_ui (EogPlugin *plugin,
-		EogWindow *window)
-{
-}
-
 static void
 eog_reload_plugin_class_init (EogReloadPluginClass *klass)
 {
@@ -155,5 +151,4 @@ eog_reload_plugin_class_init (EogReloadPluginClass *klass)
 
 	plugin_class->activate = impl_activate;
 	plugin_class->deactivate = impl_deactivate;
-	plugin_class->update_ui = impl_update_ui;
 }
